Range-v3: ranges::v3::concepts::Writable Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Types | Public Member Functions | List of all members
ranges::v3::concepts::Writable Struct Reference

## Public Types
template<typename Out >
using | reference_t = Readable::reference_t< Out >

## Public Member Functions
template<typename Out , typename T >
auto | requires_ (Out &&o, T &&t) -> decltype(concepts::valid_expr(((void)(*o=(T &&) t), 42),((void)(*((Out &&) o)=(T &&) t), 42),((void)(const_cast< reference_t< Out > const &&>(*o)=(T &&) t), 42),((void)(const_cast< reference_t< Out > const &&>(*((Out &&) o))=(T &&) t), 42)))